@@ -12,11 +12,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.!
 
-#include "char_model_trainer.h"
-
 #include <cmath>
 
 #include "char_model.h"
+#include "char_model_trainer.h"
 #include "util.h"
 
 namespace sentencepiece {
@@ -38,7 +37,7 @@ util::Status Trainer::Train() {
     sum += it.second;
   }
 
-  const float logsum = static_cast<float>(log(static_cast<long double>(sum)));
+  const auto logsum = static_cast<float>(log(static_cast<long double>(sum)));
 
   CHECK_OR_RETURN(final_pieces_.empty());
   for (const auto &it : Sorted(required_chars_)) {
@@ -46,8 +45,9 @@ util::Status Trainer::Train() {
         final_pieces_.size() == static_cast<size_t>(vocab_size)) {
       break;
     }
-    final_pieces_.emplace_back(string_util::UnicodeCharToUTF8(it.first),
-                               static_cast<float>(log(static_cast<long double>(it.second))) - logsum);
+    final_pieces_.emplace_back(
+        string_util::UnicodeCharToUTF8(it.first),
+        static_cast<float>(log(static_cast<long double>(it.second))) - logsum);
   }
 
   if (trainer_spec_.use_all_vocab()) {
